@@ -1,6 +1,7 @@
 #![allow(clippy::new_without_default)]
 
 pub use crate::connector::SlackClientHyperConnector;
+pub use crate::connector::SlackClientHyperHttpsConnector;
 use slack_morphism::SlackClient;
 
 pub mod connector;
@@ -8,7 +9,7 @@ pub mod listener;
 pub mod scroller_ext;
 mod socket_mode;
 
-pub type SlackHyperClient = SlackClient<SlackClientHyperConnector>;
+pub type SlackHyperClient = SlackClient<SlackClientHyperHttpsConnector>;
 
 pub use listener::chain_service_routes_fn;
 pub use listener::SlackClientEventsHyperListener;
